@@ -1410,7 +1410,7 @@ add_item (struct AddDirClientContext *adcc,
   struct stat sbuf;
   uint64_t fsize;
 
-  if (0 != STAT (item->filename, &sbuf))
+  if (0 != stat (item->filename, &sbuf))
   {
     GNUNET_log_strerror_file (GNUNET_ERROR_TYPE_ERROR, "stat", item->filename);
     return;
